@@ -348,7 +348,8 @@ vardom <- function(Y, H, PSU, w_final,
                           PSU_level = PSU_level,
                           PSU_sort = PSU_sort,
                           period = period,
-                          dataset = NULL)
+                          dataset = NULL,
+                          msg="Current variance estimation")
   var_est <- transpos(var_est, is.null(period), "var_est", names(period))
   all_result <- var_est
     
@@ -362,7 +363,8 @@ vardom <- function(Y, H, PSU, w_final,
                              PSU_level = PSU_level,
                              PSU_sort = PSU_sort,
                              period = period,
-                             dataset = NULL)
+                             dataset = NULL,
+                             msg="Variance of HT estimator under current design")
   var_cur_HT <- transpos(var_cur_HT, is.null(period), "var_cur_HT", names(period))
   all_result <- merge(all_result, var_cur_HT, all=TRUE)
   n_nonzero <- var_est <- var_cur_HT <- NULL
