@@ -701,7 +701,8 @@ varpoord <- function(Y, w_final,
 
   var_est <- variance_est(Y=Y4, H=H, PSU=PSU, w_final=w_final2,
                           N_h=N_h, fh_zero=fh_zero, PSU_level=PSU_level,
-                          period=period, dataset=NULL)   
+                          period=period, dataset=NULL, 
+                          msg="Current variance estimation")
   var_est <- transpos(var_est, is.null(period), "var_est", names(period))
   all_result <- var_est
 
@@ -709,7 +710,8 @@ varpoord <- function(Y, w_final,
   # Variance of HT estimator under current design
   var_cur_HT <- variance_est(Y=Y3a, H=H, PSU=PSU, w_final=w_design2, 
                              N_h=N_h, fh_zero=fh_zero, PSU_level=PSU_level,
-                             period=period, dataset=NULL)                          
+                             period=period, dataset=NULL,
+                             msg="Variance of HT estimator under current design")                          
   var_cur_HT <- transpos(var_cur_HT, is.null(period), "var_cur_HT", names(period))
   all_result <- merge(all_result, var_cur_HT)
   var_est <- var_cur_HT <- NULL
